pub struct ActionArtifact {
pub archive_download_url: Option<String>,
pub created_at: Option<OffsetDateTime>,
pub expired: Option<bool>,
pub expires_at: Option<OffsetDateTime>,
pub id: Option<i64>,
pub name: Option<String>,
pub run_id: Option<i64>,
pub size_in_bytes: Option<i64>,
pub updated_at: Option<OffsetDateTime>,
}Expand description
ActionArtifact represents an artifact of a workflow run
Fields
archive_download_url: Option<String>the URL to download the artifact zip archive
created_at: Option<OffsetDateTime>expired: Option<bool>whether the artifact has expired
expires_at: Option<OffsetDateTime>id: Option<i64>the artifact’s ID
name: Option<String>the artifact’s name
run_id: Option<i64>the ID of the workflow run that produced this artifact
size_in_bytes: Option<i64>the total size of the artifact in bytes
updated_at: Option<OffsetDateTime>Trait Implementations
Sourceimpl Clone for ActionArtifact
impl Clone for ActionArtifact
Sourcefn clone(&self) -> ActionArtifact
fn clone(&self) -> ActionArtifact
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ActionArtifact
impl Debug for ActionArtifact
Sourceimpl<'de> Deserialize<'de> for ActionArtifact
impl<'de> Deserialize<'de> for ActionArtifact
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl FromResponse for ActionArtifact
impl FromResponse for ActionArtifact
fn from_response( response: ApiResponse, has_body: bool, ) -> Result<Self, StructureError>
Sourceimpl PartialEq for ActionArtifact
impl PartialEq for ActionArtifact
Sourcefn eq(&self, other: &ActionArtifact) -> bool
fn eq(&self, other: &ActionArtifact) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for ActionArtifact
impl Serialize for ActionArtifact
impl StructuralPartialEq for ActionArtifact