pub struct ActionRunner {
pub description: Option<String>,
pub ephemeral: Option<bool>,
pub id: Option<i64>,
pub labels: Option<Vec<String>>,
pub name: Option<String>,
pub owner_id: Option<i64>,
pub repo_id: Option<i64>,
pub status: Option<ActionRunnerStatus>,
pub uuid: Option<String>,
pub version: Option<String>,
}Expand description
ActionRunner represents a runner
Fields
description: Option<String>Description provides optional details about this runner.
ephemeral: Option<bool>Indicates if runner is ephemeral runner
id: Option<i64>ID uniquely identifies this runner.
labels: Option<Vec<String>>Labels is a list of labels attached to this runner.
name: Option<String>Name of the runner; not unique.
owner_id: Option<i64>OwnerID is the identifier of the user or organization this runner belongs to. O if the runner is owned by a
repository.
repo_id: Option<i64>RepoID is the identifier of the repository this runner belongs to. 0 if the runner belongs to a user or
organization.
status: Option<ActionRunnerStatus>Status indicates whether this runner is offline, or active, for example.
uuid: Option<String>UUID uniquely identifies this runner.
version: Option<String>Version is the self-reported version string of Forgejo Runner.