pub struct Comment {
pub assets: Option<Vec<Attachment>>,
pub body: Option<String>,
pub created_at: Option<OffsetDateTime>,
pub html_url: Option<Url>,
pub id: Option<i64>,
pub issue_url: Option<Url>,
pub original_author: Option<String>,
pub original_author_id: Option<i64>,
pub pull_request_url: Option<Url>,
pub updated_at: Option<OffsetDateTime>,
pub user: Option<User>,
}Expand description
Comment represents a comment on a commit or issue
Fields
assets: Option<Vec<Attachment>>The attachments to the comment
body: Option<String>The body of the comment
created_at: Option<OffsetDateTime>The time of the comment’s creation
html_url: Option<Url>The HTML URL of the comment
id: Option<i64>The identifier of the comment
issue_url: Option<Url>The HTML URL of the issue if the comment is posted on an issue, else empty string
The original author that posted the comment if it was not posted locally, else empty string
The ID of the original author that posted the comment if it was not posted locally, else 0
pull_request_url: Option<Url>The HTML URL of the pull request if the comment is posted on a pull request, else empty string
updated_at: Option<OffsetDateTime>The time of the comment’s update
user: Option<User>Trait Implementations
Sourceimpl<'de> Deserialize<'de> for Comment
impl<'de> Deserialize<'de> for Comment
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl FromResponse for Comment
impl FromResponse for Comment
fn from_response( response: ApiResponse, has_body: bool, ) -> Result<Self, StructureError>
impl StructuralPartialEq for Comment