pub struct ListActionTasksQuery {
pub status: Option<Vec<ListActionTasksQueryStatus>>,
}Fields
status: Option<Vec<ListActionTasksQueryStatus>>Returns workflow tasks with the check run status or conclusion that is specified.
For example, a conclusion can be success or a status can be in_progress.