pub struct RepoGetActionJobLogsQuery {
pub attempt: Option<i64>,
}Fields
attempt: Option<i64>1-based attempt number matching the value of attempt in the job listing; omit to fetch the latest attempt of the job