pub struct UpdateFileOptions {
pub author: Option<Identity>,
pub branch: Option<String>,
pub committer: Option<Identity>,
pub content: String,
pub dates: Option<CommitDateOptions>,
pub force_overwrite_new_branch: Option<bool>,
pub from_path: Option<String>,
pub message: Option<String>,
pub new_branch: Option<String>,
pub sha: String,
pub signoff: Option<bool>,
}Expand description
UpdateFileOptions options for updating files
Note: author and committer are optional (if only one is given, it will be used for the other, otherwise the authenticated user will be used)
Fields
branch: Option<String>branch (optional) to base this file from. if not given, the default branch is used
committer: Option<Identity>content: Stringcontent must be base64 encoded
dates: Option<CommitDateOptions>force_overwrite_new_branch: Option<bool>(optional) will do a force-push if the new branch already exists
from_path: Option<String>from_path (optional) is the path of the original file which will be moved/renamed to the path in the URL
message: Option<String>message (optional) for the commit of this file. if not supplied, a default message will be used
new_branch: Option<String>new_branch (optional) will make a new branch from branch before creating the file
sha: Stringsha is the SHA for the file that already exists
signoff: Option<bool>Add a Signed-off-by trailer by the committer at the end of the commit log message.